Class: Mailosaur::Models::MessageForwardOptions
- Defined in:
- lib/Mailosaur/models/message_forward_options.rb
Instance Attribute Summary collapse
-
#cc ⇒ String
Must be a verified email address.
-
#html ⇒ String
with.
-
#text ⇒ String
email with.
-
#to ⇒ String
Must be a verified email address.
Instance Method Summary collapse
-
#initialize(data = {}) ⇒ MessageForwardOptions
constructor
A new instance of MessageForwardOptions.
Methods inherited from BaseModel
Constructor Details
#initialize(data = {}) ⇒ MessageForwardOptions
Returns a new instance of MessageForwardOptions.
4 5 6 7 8 9 |
# File 'lib/Mailosaur/models/message_forward_options.rb', line 4 def initialize(data = {}) @to = data['to'] @cc = data['cc'] @text = data['text'] @html = data['html'] end |
Instance Attribute Details
#cc ⇒ String
Must be a verified email address.
17 18 19 |
# File 'lib/Mailosaur/models/message_forward_options.rb', line 17 def cc @cc end |
#html ⇒ String
with. Note that only html or text can be supplied, not both.
25 26 27 |
# File 'lib/Mailosaur/models/message_forward_options.rb', line 25 def html @html end |
#text ⇒ String
email with. Note that only text or html can be supplied, not both.
21 22 23 |
# File 'lib/Mailosaur/models/message_forward_options.rb', line 21 def text @text end |
#to ⇒ String
Must be a verified email address.
13 14 15 |
# File 'lib/Mailosaur/models/message_forward_options.rb', line 13 def to @to end |