Class: Mailosaur::Models::MessageReplyOptions

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/Mailosaur/models/message_reply_options.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#to_json

Constructor Details

#initialize(data = {}) ⇒ MessageReplyOptions

Returns a new instance of MessageReplyOptions.



4
5
6
7
8
9
# File 'lib/Mailosaur/models/message_reply_options.rb', line 4

def initialize(data = {})
  @cc = data['cc']
  @text = data['text']
  @html = data['html']
  @attachments = data['attachments']
end

Instance Attribute Details

#attachmentsArray<Attachment>

Returns Any message attachments.

Returns:

  • (Array<Attachment>)

    Any message attachments.



24
25
26
# File 'lib/Mailosaur/models/message_reply_options.rb', line 24

def attachments
  @attachments
end

#ccString

Must be a verified email address.

Returns:

  • (String)

    The email address to which the email will be CC’d.



13
14
15
# File 'lib/Mailosaur/models/message_reply_options.rb', line 13

def cc
  @cc
end

#htmlString

reply. Note that only html or text can be supplied, not both.

Returns:

  • (String)

    Any additional HTML content to include in the



21
22
23
# File 'lib/Mailosaur/models/message_reply_options.rb', line 21

def html
  @html
end

#textString

the reply. Note that only text or html can be supplied, not both.

Returns:

  • (String)

    Any additional plain text content to include in



17
18
19
# File 'lib/Mailosaur/models/message_reply_options.rb', line 17

def text
  @text
end