Class: Mailosaur::Models::MessageReplyOptions
- Defined in:
- lib/Mailosaur/models/message_reply_options.rb
Instance Attribute Summary collapse
-
#attachments ⇒ Array<Attachment>
Any message attachments.
-
#cc ⇒ String
Must be a verified email address.
-
#html ⇒ String
reply.
-
#text ⇒ String
the reply.
Instance Method Summary collapse
-
#initialize(data = {}) ⇒ MessageReplyOptions
constructor
A new instance of MessageReplyOptions.
Methods inherited from BaseModel
Constructor Details
#initialize(data = {}) ⇒ MessageReplyOptions
Returns a new instance of MessageReplyOptions.
4 5 6 7 8 9 |
# File 'lib/Mailosaur/models/message_reply_options.rb', line 4 def initialize(data = {}) @cc = data['cc'] @text = data['text'] @html = data['html'] = data['attachments'] end |
Instance Attribute Details
#attachments ⇒ Array<Attachment>
Returns Any message attachments.
24 25 26 |
# File 'lib/Mailosaur/models/message_reply_options.rb', line 24 def end |
#cc ⇒ String
Must be a verified email address.
13 14 15 |
# File 'lib/Mailosaur/models/message_reply_options.rb', line 13 def cc @cc end |
#html ⇒ String
reply. Note that only html or text can be supplied, not both.
21 22 23 |
# File 'lib/Mailosaur/models/message_reply_options.rb', line 21 def html @html end |
#text ⇒ String
the reply. Note that only text or html can be supplied, not both.
17 18 19 |
# File 'lib/Mailosaur/models/message_reply_options.rb', line 17 def text @text end |